import React, { useState, useContext } from 'react';
import PropTypes from 'prop-types';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};

  var target = _objectWithoutPropertiesLoose(source, excluded);

  var key, i;

  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);

    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }

  return target;
}

function _slicedToArray(arr, i) {
  return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest();
}

function _arrayWithHoles(arr) {
  if (Array.isArray(arr)) return arr;
}

function _iterableToArrayLimit(arr, i) {
  if (!(Symbol.iterator in Object(arr) || Object.prototype.toString.call(arr) === "[object Arguments]")) {
    return;
  }

  var _arr = [];
  var _n = true;
  var _d = false;
  var _e = undefined;

  try {
    for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) {
      _arr.push(_s.value);

      if (i && _arr.length === i) break;
    }
  } catch (err) {
    _d = true;
    _e = err;
  } finally {
    try {
      if (!_n && _i["return"] != null) _i["return"]();
    } finally {
      if (_d) throw _e;
    }
  }

  return _arr;
}

function _nonIterableRest() {
  throw new TypeError("Invalid attempt to destructure non-iterable instance");
}

var FormContext = React.createContext(null);
function useForm(initialState) {
  var _useState = useState(initialState),
      _useState2 = _slicedToArray(_useState, 2),
      formState = _useState2[0],
      setFormState = _useState2[1];

  return {
    update: function update(name, value) {
      setFormState(_objectSpread2({}, formState, _defineProperty({}, name, value)));
    },
    getFormData: function getFormData() {
      return formState;
    },
    getValue: function getValue(name) {
      return formState[name];
    },
    reset: function reset() {
      setFormState(initialState);
    }
  };
}
function handleInputChange(formState, event) {
  var target = event.target;
  var value = target.type === 'checkbox' ? target.checked : target.value;
  var name = target.name;
  formState.update(name, value);
}

function FormActions(_ref) {
  var submitLabel = _ref.submitLabel,
      cancelLabel = _ref.cancelLabel,
      onCancel = _ref.onCancel;
  return React.createElement("div", {
    className: "form-actions"
  }, React.createElement("button", {
    type: "submit",
    className: "btn btn-primary mr-1"
  }, submitLabel), React.createElement("button", {
    type: "button",
    className: "btn btn-secondary",
    onClick: onCancel
  }, cancelLabel));
}
FormActions.propTypes = {
  submitLabel: PropTypes.string,
  cancelLabel: PropTypes.string,
  onCancel: PropTypes.func.isRequired
};

function Form(_ref) {
  var children = _ref.children,
      initialValues = _ref.initialValues,
      onSubmit = _ref.onSubmit,
      submitLabel = _ref.submitLabel,
      cancelLabel = _ref.cancelLabel,
      onCancel = _ref.onCancel;
  var formState = useForm(initialValues);

  function handleSubmit(e) {
    e.preventDefault();
    var res = onSubmit(formState.getFormData(), function () {
      return formState.reset();
    });

    if (res && res.then) {
      res.then(function () {
        formState.reset();
      });
    }
  }

  function handleCancel() {
    //TODO: improve cancel options
    onCancel();
  }

  return React.createElement("form", {
    onSubmit: handleSubmit
  }, React.createElement(FormContext.Provider, {
    value: formState
  }, children), React.createElement(FormActions, {
    submitLabel: submitLabel,
    cancelLabel: cancelLabel,
    onCancel: handleCancel
  }));
}
Form.defaultProps = {
  submitLabel: 'Submit',
  cancelLabel: 'Cancel'
};
Form.propTypes = {
  submitLabel: PropTypes.string,
  onSubmit: PropTypes.func.isRequired,
  cancelLabel: PropTypes.string,
  onCancel: PropTypes.func.isRequired,
  children: PropTypes.oneOfType([PropTypes.element, PropTypes.arrayOf(PropTypes.element)]),
  initialValues: PropTypes.object
};

function FormCheckbox(_ref) {
  var id = _ref.id,
      name = _ref.name,
      required = _ref.required,
      valueLabel = _ref.valueLabel;
  var formState = useContext(FormContext);
  var value = formState.getValue(name) || false;
  return React.createElement("div", {
    className: "custom-control custom-checkbox"
  }, React.createElement("input", _extends({
    required: required,
    name: name,
    id: id
  }, {
    type: "checkbox",
    className: "custom-control-input",
    onChange: handleInputChange.bind(null, formState),
    checked: value
  })), React.createElement("label", {
    className: "custom-control-label",
    htmlFor: id
  }, valueLabel));
}
FormCheckbox.propTypes = {
  id: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  valueLabel: PropTypes.string,
  required: PropTypes.any
};

function FormInput(_ref) {
  var id = _ref.id,
      type = _ref.type,
      name = _ref.name,
      required = _ref.required,
      placeholder = _ref.placeholder;
  var formState = useContext(FormContext);
  return React.createElement("input", _extends({
    required: required,
    name: name,
    id: id,
    placeholder: placeholder,
    type: type
  }, {
    className: "form-control",
    onChange: handleInputChange.bind(null, formState),
    value: formState.getValue(name) || ''
  }));
}
FormInput.defaultProps = {
  type: 'text'
};
FormInput.propTypes = {
  id: PropTypes.string,
  type: PropTypes.string,
  name: PropTypes.string.isRequired,
  placeholder: PropTypes.string,
  required: PropTypes.any
};

function FormLabel(_ref) {
  var id = _ref.id,
      label = _ref.label;
  return React.createElement("label", {
    htmlFor: id
  }, label);
}
FormLabel.propTypes = {
  id: PropTypes.string,
  label: PropTypes.string
};

function FormRadio(_ref) {
  var id = _ref.id,
      name = _ref.name,
      required = _ref.required,
      checkedValue = _ref.checkedValue,
      valueLabel = _ref.valueLabel,
      inline = _ref.inline;
  var formState = useContext(FormContext);
  var value = formState.getValue(name) || false;
  return React.createElement("div", {
    className: "custom-control custom-radio ".concat(inline ? 'custom-control-inline' : '')
  }, React.createElement("input", _extends({
    required: required,
    name: name,
    id: id
  }, {
    type: "radio",
    className: "custom-control-input",
    onChange: handleInputChange.bind(null, formState),
    checked: value === checkedValue,
    value: checkedValue
  })), React.createElement("label", {
    className: "custom-control-label",
    htmlFor: id
  }, valueLabel));
}
FormRadio.defaultProps = {
  inline: false
};
FormRadio.propTypes = {
  id: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  valueLabel: PropTypes.string,
  inline: PropTypes.bool,
  required: PropTypes.any,
  checkedValue: PropTypes.any
};

function FormSelect(_ref) {
  var id = _ref.id,
      name = _ref.name,
      options = _ref.options,
      required = _ref.required,
      placeholder = _ref.placeholder;
  var formState = useContext(FormContext);
  return React.createElement("select", _extends({
    required: required,
    name: name,
    id: id
  }, {
    className: "form-control",
    onChange: handleInputChange.bind(null, formState),
    value: formState.getValue(name) || ''
  }), React.createElement("option", {
    value: ""
  }, placeholder), renderOptions(options, formState.getFormData()));
}
FormSelect.propTypes = {
  id: PropTypes.string,
  options: PropTypes.oneOfType([PropTypes.func, PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.object]))]),
  name: PropTypes.string.isRequired,
  placeholder: PropTypes.string,
  required: PropTypes.any
};

function renderOptions(options, formData) {
  var _options = typeof options === 'function' ? options(formData) : options;

  if (!Array.isArray(_options)) {
    throw new Error('Select Options should be an array');
  }

  return _options.map(function (option, index) {
    var value, label;

    if (typeof option === 'string') {
      value = label = option;
    } else {
      value = option.value;
      label = option.label;
    }

    return React.createElement("option", {
      key: index,
      value: value
    }, label);
  });
}

function FormSwitch(_ref) {
  var id = _ref.id,
      name = _ref.name,
      required = _ref.required,
      trueLabel = _ref.trueLabel,
      falseLabel = _ref.falseLabel;
  var formState = useContext(FormContext);
  var value = formState.getValue(name) || false;
  return React.createElement("div", {
    className: "custom-control custom-switch"
  }, React.createElement("input", _extends({
    required: required,
    name: name,
    id: id
  }, {
    type: "checkbox",
    className: "custom-control-input",
    onChange: handleInputChange.bind(null, formState),
    checked: value
  })), React.createElement("label", {
    className: "custom-control-label",
    htmlFor: id
  }, (trueLabel || falseLabel) && (value ? trueLabel : falseLabel)));
}
FormSwitch.propTypes = {
  id: PropTypes.string.isRequired,
  name: PropTypes.string.isRequired,
  trueLabel: PropTypes.string,
  falseLabel: PropTypes.string,
  required: PropTypes.any
};

function FormTextarea(_ref) {
  var id = _ref.id,
      name = _ref.name,
      required = _ref.required,
      placeholder = _ref.placeholder,
      rows = _ref.rows;
  var formState = useContext(FormContext);
  return React.createElement("textarea", _extends({
    required: required,
    name: name,
    id: id,
    placeholder: placeholder,
    rows: rows
  }, {
    className: "form-control",
    onChange: handleInputChange.bind(null, formState),
    value: formState.getValue(name) || ''
  }));
}
FormTextarea.defaultProps = {
  rows: 5
};
FormTextarea.propTypes = {
  id: PropTypes.string,
  name: PropTypes.string.isRequired,
  required: PropTypes.any,
  placeholder: PropTypes.string,
  rows: PropTypes.number
};

function FormGroup(_ref) {
  var children = _ref.children,
      props = _objectWithoutProperties(_ref, ["children"]);

  return React.createElement("div", {
    className: "form-group"
  }, React.createElement(FormLabel, props), children);
}

FormGroup.propTypes = {
  children: PropTypes.element
};
function FormGroupCheckbox(props) {
  return React.createElement(FormGroup, props, React.createElement(FormCheckbox, props));
}
function FormGroupInput(props) {
  return React.createElement(FormGroup, props, React.createElement(FormInput, props));
}
function FormGroupRadio(_ref2) {
  var options = _ref2.options,
      id = _ref2.id,
      props = _objectWithoutProperties(_ref2, ["options", "id"]);

  return React.createElement(FormGroup, props, React.createElement("div", null, options.map(function (option, index) {
    return React.createElement(FormRadio, _extends({
      key: index
    }, props, {
      checkedValue: option.value,
      valueLabel: option.label,
      id: "".concat(id, "-").concat(index)
    }));
  })));
}
FormGroupRadio.defaultProps = {
  inline: true
};
FormGroupRadio.propTypes = {
  id: PropTypes.string,
  options: PropTypes.arrayOf(PropTypes.object),
  inline: PropTypes.bool
};
function FormGroupSelect(props) {
  return React.createElement(FormGroup, props, React.createElement(FormSelect, props));
}
function FormGroupSwitch(props) {
  return React.createElement(FormGroup, props, React.createElement(FormSwitch, props));
}
function FormGroupTextarea(props) {
  return React.createElement(FormGroup, props, React.createElement(FormTextarea, props));
}

function normalizeColumns(columns) {
  return columns.map(function (column) {
    if (typeof column !== 'string') {
      return column;
    }

    return {
      attribute: column,
      label: column
    };
  });
}
function getColumnClass(_ref) {
  var align = _ref.align;
  var classes = [align === 'center' ? 'text-center' : align === 'right' ? 'text-right' : ''];
  return classes.join(' ');
}

function TableHead(_ref) {
  var columns = _ref.columns,
      actions = _ref.actions,
      actionLabel = _ref.actionLabel;
  return React.createElement("thead", null, React.createElement("tr", null, columns.map(function (column, columnIndex) {
    return React.createElement("th", {
      key: columnIndex,
      className: getColumnClass(column)
    }, column.label);
  }), actions && React.createElement("th", {
    className: "text-center"
  }, actionLabel)));
}
TableHead.propTypes = {
  actionLabel: PropTypes.string,
  actions: PropTypes.arrayOf(PropTypes.object),
  columns: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.object]))
};

function TableBody(_ref) {
  var columns = _ref.columns,
      docs = _ref.docs,
      rowClass = _ref.rowClass,
      actions = _ref.actions;
  return React.createElement("tbody", null, docs.map(function (doc, docIndex) {
    return React.createElement("tr", {
      key: docIndex,
      className: rowClass(doc)
    }, columns.map(function (column, columnIndex) {
      return React.createElement("td", {
        key: columnIndex,
        className: getColumnClass(column)
      }, getColumnValue(doc, column, docIndex));
    }), actions && React.createElement("td", {
      className: "text-center"
    }, actions.map(function (action, actionIndex) {
      return React.createElement("a", _extends({
        key: actionIndex,
        title: action.title
      }, getActionProps(action, doc), {
        className: actionIndex > 0 ? 'ml-2' : ''
      }), action.content);
    })));
  }));
}
TableBody.propTypes = {
  actions: PropTypes.arrayOf(PropTypes.object),
  columns: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.object])),
  docs: PropTypes.arrayOf(PropTypes.object),
  rowClass: PropTypes.func
};

function getColumnValue(doc, column, docIndex) {
  var rawValue = doc[column.attribute];

  if (!column.format) {
    return rawValue;
  }

  return column.format(rawValue, doc, docIndex);
}

function getActionProps(action, doc) {
  var props = {};

  if (action.onClick) {
    props.href = '';

    props.onClick = function (e) {
      e.stopPropagation();
      e.preventDefault();
      action.onClick(doc);
    };
  } else if (action.link) {
    props.href = action.link(doc);
  }

  return props;
}

function Table(_ref) {
  var docs = _ref.docs,
      columns = _ref.columns,
      striped = _ref.striped,
      bordered = _ref.bordered,
      hover = _ref.hover,
      small = _ref.small,
      dark = _ref.dark,
      rowClass = _ref.rowClass,
      caption = _ref.caption,
      actions = _ref.actions,
      actionLabel = _ref.actionLabel;
  var normalizedColumns = normalizeColumns(columns);
  var tableClasses = ['table', striped && 'table-striped', bordered && 'table-bordered', hover && 'table-hover', small && 'table-sm', dark && 'table-dark'].join(' ');
  return React.createElement("div", {
    className: "table-responsive"
  }, React.createElement("table", {
    className: tableClasses
  }, caption && React.createElement("caption", null, caption), React.createElement(TableHead, _extends({
    actions: actions,
    actionLabel: actionLabel
  }, {
    columns: normalizedColumns
  })), React.createElement(TableBody, _extends({
    docs: docs,
    rowClass: rowClass,
    actions: actions
  }, {
    columns: normalizedColumns
  }))));
}
Table.defaultProps = {
  striped: true,
  bordered: false,
  hover: true,
  small: true,
  dark: false,
  actionLabel: 'Actions',
  rowClass: function rowClass() {
    return '';
  }
};
Table.propTypes = {
  actions: PropTypes.arrayOf(PropTypes.object),
  columns: PropTypes.arrayOf(PropTypes.oneOfType([PropTypes.string, PropTypes.object])),
  docs: PropTypes.arrayOf(PropTypes.object),
  rowClass: PropTypes.func,
  striped: PropTypes.bool,
  bordered: PropTypes.bool,
  hover: PropTypes.bool,
  small: PropTypes.bool,
  dark: PropTypes.bool,
  caption: PropTypes.oneOfType([PropTypes.string, PropTypes.element]),
  actionLabel: PropTypes.string
};

function TabHeader(_ref) {
  var index = _ref.index,
      isActive = _ref.isActive,
      title = _ref.title,
      onSelect = _ref.onSelect;
  return React.createElement("li", {
    className: "nav-item"
  }, React.createElement("a", {
    className: "nav-link ".concat(isActive ? 'active' : '') // id="home-tab"
    ,
    "data-toggle": "tab",
    href: "" // href="#home"
    ,
    onClick: safeClick(onSelect, index),
    role: "tab" // aria-controls="home"
    ,
    "aria-selected": isActive
  }, title));
}
TabHeader.propTypes = {
  index: PropTypes.number,
  isActive: PropTypes.bool,
  title: PropTypes.string,
  onSelect: PropTypes.func
};

function safeClick(callback, index) {
  return function (e) {
    e.stopPropagation();
    e.preventDefault();
    callback(index);
  };
}

function TabContent(_ref) {
  var isActive = _ref.isActive,
      content = _ref.content;
  return React.createElement("div", {
    className: "tab-pane fade ".concat(isActive ? 'show active' : '') // id="home"
    ,
    role: "tabpanel" // aria-labelledby="home-tab"

  }, content);
}
TabContent.propTypes = {
  isActive: PropTypes.bool,
  content: PropTypes.oneOfType([PropTypes.element, PropTypes.string])
};

function Tabs(_ref) {
  var vertical = _ref.vertical,
      tabs = _ref.tabs,
      activeTab = _ref.activeTab,
      onlyRenderActiveTab = _ref.onlyRenderActiveTab,
      bordered = _ref.bordered,
      onSelect = _ref.onSelect;

  if (activeTab >= tabs.length) {
    console.warn('Invalid tab selected:', activeTab);
  }

  return React.createElement("div", {
    className: "custom-tabs-container ".concat(vertical ? 'd-flex' : '')
  }, React.createElement("div", {
    className: "tabs-navigation"
  }, React.createElement("ul", {
    className: "nav ".concat(vertical ? 'nav-pills flex-column' : 'nav-tabs'),
    id: "myTab",
    role: "tablist"
  }, tabs.map(function (tab, tabIndex) {
    return React.createElement(TabHeader, {
      key: tabIndex,
      index: tabIndex,
      isActive: tabIndex === activeTab,
      title: tab.title,
      onSelect: onSelect
    });
  }))), React.createElement("div", {
    className: "tab-content ".concat(vertical ? 'flex-fill ml-3' : "".concat(bordered ? 'border-left border-right border-bottom p-2' : 'py-2')) // id="myTabContent"

  }, onlyRenderActiveTab ? React.createElement(TabContent, {
    isActive: true,
    content: tabs[activeTab] && tabs[activeTab].content
  }) : tabs.map(function (tab, tabIndex) {
    return React.createElement(TabContent, {
      key: tabIndex,
      isActive: tabIndex === activeTab,
      content: tab.content
    });
  })));
}
Tabs.defaultProps = {
  vertical: false,
  bordered: false,
  activeTab: 0,
  onlyRenderActiveTab: false,
  onSelect: function onSelect() {}
};
Tabs.propTypes = {
  vertical: PropTypes.bool,
  tabs: PropTypes.arrayOf(PropTypes.object),
  activeTab: PropTypes.number,
  onlyRenderActiveTab: PropTypes.bool,
  bordered: PropTypes.bool,
  onSelect: PropTypes.func
};

function StatefulTabs(_ref) {
  var initialTab = _ref.initialTab,
      _ = _ref.activeTab,
      tabs = _ref.tabs,
      props = _objectWithoutProperties(_ref, ["initialTab", "activeTab", "tabs"]);

  var _useTabs = useTabs(tabs, initialTab),
      getSelected = _useTabs.getSelected,
      select = _useTabs.select;

  return React.createElement(Tabs, _extends({
    tabs: tabs
  }, props, {
    activeTab: getSelected(),
    onSelect: select
  }));
}
StatefulTabs.propTypes = {
  activeTab: PropTypes.any,
  tabs: PropTypes.arrayOf(PropTypes.object),
  initialTab: PropTypes.number
};

function useTabs(tabs, initialTab) {
  var _useState = useState(initialTab < tabs.length ? initialTab : 0),
      _useState2 = _slicedToArray(_useState, 2),
      activeTab = _useState2[0],
      setActiveTab = _useState2[1];

  return {
    getSelected: function getSelected() {
      return activeTab;
    },
    select: function select(index) {
      if (index >= tabs.length) {
        throw new Error('Invalid tab');
      }

      setActiveTab(index);
    }
  };
}

function Pagination(_ref) {
  var actualPage = _ref.actualPage,
      ariaLabel = _ref.ariaLabel,
      firstLabel = _ref.firstLabel,
      lastLabel = _ref.lastLabel,
      lastPage = _ref.lastPage,
      maxPageWindow = _ref.maxPageWindow,
      nextLabel = _ref.nextLabel,
      onSelect = _ref.onSelect,
      previousLabel = _ref.previousLabel;
  var pageWindow = Math.min(maxPageWindow, lastPage);
  var centerOfPageWindow = Math.max(Math.floor(pageWindow / 2), 2);
  var lastStartPage = Math.max(lastPage - pageWindow + 1, 1);
  var startPage = Math.max(Math.min(actualPage - centerOfPageWindow, lastStartPage), 1);
  var showPreviousNavigation = startPage > 1;
  var pages = Array.from({
    length: pageWindow
  }, function (v, i) {
    return startPage + i;
  });

  var select = function select(page) {
    return function (e) {
      e.preventDefault();
      e.stopPropagation();
      onSelect(page);
    };
  };

  return React.createElement("nav", {
    "aria-label": ariaLabel
  }, React.createElement("ul", {
    className: "pagination"
  }, showPreviousNavigation && React.createElement(React.Fragment, null, React.createElement("li", {
    className: "page-item"
  }, React.createElement("a", {
    className: "page-link",
    href: "",
    onClick: select(1),
    "aria-label": firstLabel
  }, React.createElement("span", {
    "aria-hidden": "true"
  }, "\xAB"), React.createElement("span", {
    className: "sr-only"
  }, firstLabel))), React.createElement("li", {
    className: "page-item"
  }, React.createElement("a", {
    className: "page-link",
    href: "",
    onClick: select(actualPage - 1),
    "aria-label": previousLabel
  }, React.createElement("span", {
    "aria-hidden": "true"
  }, "\u2039"), React.createElement("span", {
    className: "sr-only"
  }, previousLabel)))), pages.map(function (page) {
    return React.createElement("li", {
      key: "pages-".concat(page),
      className: "page-item".concat(actualPage === page ? ' active' : '')
    }, React.createElement("a", {
      className: "page-link",
      href: "",
      onClick: select(page)
    }, page));
  }), startPage < lastStartPage && React.createElement(React.Fragment, null, React.createElement("li", {
    className: "page-item"
  }, React.createElement("a", {
    className: "page-link",
    href: "",
    onClick: select(actualPage + 1),
    "aria-label": nextLabel
  }, React.createElement("span", {
    "aria-hidden": "true"
  }, "\u203A"), React.createElement("span", {
    className: "sr-only"
  }, nextLabel))), React.createElement("li", {
    className: "page-item"
  }, React.createElement("a", {
    className: "page-link",
    href: "",
    onClick: select(lastPage),
    "aria-label": lastLabel
  }, React.createElement("span", {
    "aria-hidden": "true"
  }, "\xBB"), React.createElement("span", {
    className: "sr-only"
  }, lastLabel))))));
}
Pagination.defaultProps = {
  actualPage: 1,
  ariaLabel: 'Page navigation',
  firstLabel: 'First',
  lastLabel: 'Last',
  maxPageWindow: 5,
  nextLabel: 'Next',
  previousLabel: 'Previous'
};
Pagination.propTypes = {
  actualPage: PropTypes.number,
  ariaLabel: PropTypes.string,
  firstLabel: PropTypes.string,
  lastLabel: PropTypes.string,
  lastPage: PropTypes.number,
  maxPageWindow: PropTypes.number,
  nextLabel: PropTypes.string,
  onSelect: PropTypes.func.isRequired,
  previousLabel: PropTypes.string
};

export { Form, FormCheckbox, FormGroupCheckbox, FormGroupInput, FormGroupRadio, FormGroupSelect, FormGroupSwitch, FormGroupTextarea, FormInput, FormRadio, FormSelect, FormSwitch, FormTextarea, Pagination, StatefulTabs, TabContent, TabHeader, Table, Tabs };
